@@ -1,7 +1,6 @@
 /*
- * DEBUG: section XXX
+ * DEBUG: section 93    eCAP Interface
  */
-
 #include "squid.h"
 #include "HttpRequest.h"
 #include "HttpReply.h"
@@ -38,7 +37,8 @@ Adaptation::Ecap::HeaderRep::value(const Name &name) const
     const String value = squidId == HDR_OTHER ?
                          theHeader.getByName(name.image().c_str()) :
                          theHeader.getStrOrList(squidId);
-    return Value::FromTempString(value.termedBuf());
+    return value.defined() ?
+           Value::FromTempString(value.termedBuf()) : Value();
 }
 
 void
@@ -48,6 +48,9 @@ Adaptation::Ecap::HeaderRep::add(const Name &name, const Value &value)
     HttpHeaderEntry *e = new HttpHeaderEntry(squidId, name.image().c_str(),
             value.toString().c_str());
     theHeader.addEntry(e);
+
+    if (squidId == HDR_CONTENT_LENGTH)
+	    theMessage.content_length = theHeader.getInt64(HDR_CONTENT_LENGTH);
 }
 
 void
@@ -58,6 +61,9 @@ Adaptation::Ecap::HeaderRep::removeAny(const Name &name)
         theHeader.delByName(name.image().c_str());
     else
         theHeader.delById(squidId);
+
+    if (squidId == HDR_CONTENT_LENGTH)
+	    theMessage.content_length = theHeader.getInt64(HDR_CONTENT_LENGTH);
 }
 
 libecap::Area
@@ -142,6 +148,8 @@ Adaptation::Ecap::FirstLineRep::protocol() const
         return protocolCacheObj;
     case PROTO_INTERNAL:
         return protocolInternal;
+    case PROTO_ICY:
+        return Name();
     case PROTO_NONE:
         return Name();
 
